from reportlab.platypus import SimpleDocTemplate, Table, Paragraph, Spacer, TableStyle, Image
from reportlab.lib.styles import getSampleStyleSheet
from reportlab.lib.units import inch
from reportlab.lib import colors
from reportlab.lib.pagesizes import A4, landscape
import datetime
import json


def cambiar_formato_archivo(ruta):
    ruta_nueva = ruta.replace(".json", ".pdf")

    return ruta_nueva

def GenerarReporte(reporte):
    ruta = cambiar_formato_archivo(reporte)
    doc = SimpleDocTemplate(
        ruta,
        rightMargin=72, leftMargin=72,
        topMargin=72, bottomMargin=18,
        pagesize=A4
    )
    doc.pagesize = landscape(A4)

    styles = getSampleStyleSheet()
    conjunto_lineas = []
    spacer = Spacer(1, 0.25 * inch)

    titulo = 'PRUEBA DE VALIDACION DE ENTIDADES DEL MENU DE CONFIGURACION'
    para = Paragraph(titulo, styles["Heading1"])
    conjunto_lineas.append(para)

    fecha = 'FECHA: ' + str(datetime.date.today())
    para = Paragraph(fecha, styles["Normal"])
    conjunto_lineas.append(para)

    conjunto_lineas.append(spacer)

    with open(reporte, 'r+') as json_file:
        diccionario = json.load(json_file)
        contador1 = 1

        for i in diccionario:

            opcion = diccionario[i]

            subtitulo = str(contador1) + '. ' + i
            para = Paragraph(subtitulo, styles["Heading2"])
            conjunto_lineas.append(para)

            contador2 = 1

            for elementos in opcion:
                subtitulo2 = str(contador1) + '.' + str(contador2) + '  ' + i + ' - ID: ' + str(elementos['ID'])
                para = Paragraph(subtitulo2, styles["Heading3"])
                conjunto_lineas.append(para)

                # SI EXISTE ENTIDAD CORRECTAMENTE CONFIGURADA
                if((str(elementos['Valores en excel']) == "[]") and (str(elementos['Valores en interfaz']) == "[]")):
                    data = [
                        ['Resultado'],
                        [str(elementos['Resultado'])],
                    ]

                # SI EXISTE ENTIDAD PERO NO CORRECTAMENTE CONFIGURADA O SI NO EXISTE ENTIDAD
                else:
                    data = [
                        ['Resultado', 'Valores en excel', 'Valores en interfaz'],
                        [str(elementos['Resultado']), str(elementos['Valores en excel']),
                         str(elementos['Valores en interfaz'])],
                    ]

                tblstyle = TableStyle([
                    ('INNERGRID', (0, 0), (-1, -1), 0.25, colors.black),
                    ('BOX', (0, 0), (-1, -1), 0.25, colors.black),
                    ('ALIGN', (0, -1), (-1, -1), 'CENTER'),
                ])

                textoNuevoFormato = getSampleStyleSheet()
                textoNuevoFormato = textoNuevoFormato["BodyText"]
                textoNuevoFormato.wordWrap = 'CJK'
                data2 = [[Paragraph(cell, textoNuevoFormato) for cell in row] for row in data]

                tbl = Table(data2)
                tbl.setStyle(tblstyle)
                conjunto_lineas.append(tbl)

                if 'Subseccion' in elementos:
                    subentidades = elementos['Subseccion']
                    letra = 'A'

                    for subentidad in subentidades:
                        tipos_subentidad = list(subentidad.keys())

                        for num in range(0, len(tipos_subentidad)):
                            tipo_subentidad = tipos_subentidad[num]

                            subtitulo3 = letra + '. ' + str(tipo_subentidad)
                            para = Paragraph(subtitulo3, styles["Heading4"])
                            conjunto_lineas.append(para)

                            data = [
                                ['Resultado', 'Valores en excel', 'Valores en interfaz'],
                            ]

                            tblstyle = TableStyle([
                                ('INNERGRID', (0, 0), (-1, -1), 0.25, colors.black),
                                ('BOX', (0, 0), (-1, -1), 0.25, colors.black),
                                ('ALIGN', (0, -1), (-1, -1), 'CENTER'),
                            ])

                            filas_subentidad = subentidad[tipo_subentidad]

                            for fila in filas_subentidad:
                                print(fila['Valores en excel'])

                                # EXISTE SUBENTIDAD CORRECTAMENTE CONFIGURADA
                                if ((str(fila['Valores en excel']) == "[] ") and (
                                        str(fila['Valores en interfaz']) == "[] ")):
                                    registro = [
                                        [str(fila['Resultado']), ' - ',
                                            ' - '],
                                    ]


                                else:
                                    registro = [str(fila['Resultado']), str(fila['Valores en excel']),
                                                str(fila['Valores en interfaz'])]

                                data.append(registro)

                            textoNuevoFormato = getSampleStyleSheet()
                            textoNuevoFormato = textoNuevoFormato["BodyText"]
                            textoNuevoFormato.wordWrap = 'CJK'
                            data2 = [[Paragraph(cell, textoNuevoFormato) for cell in row] for row in data]

                            tbl = Table(data2)
                            tbl.setStyle(tblstyle)
                            conjunto_lineas.append(tbl)

                            letra = chr(ord(letra) + 1)
                contador2 = contador2 + 1
            contador1 = contador1 + 1

    doc.build(conjunto_lineas)

if __name__ == '__main__':
    ruta_reporte = input('Ingrese ruta del reporte: ')
    GenerarReporte(ruta_reporte)